@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Corporation and Contributors.
+# Copyright (c) 2005 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,15 +13,14 @@
 ##############################################################################
 """Adding that redirects to plugins.html.
 
-$Id: adding.py 69216 2006-07-19 22:05:20Z jim $
+$Id: adding.py 113109 2010-06-04 11:54:46Z janwijbrand $
 """
 
-from zope.app import zapi
-
 import zope.app.container.browser.adding
 
+from zope.traversing.browser.absoluteurl import absoluteURL
+
 class Adding(zope.app.container.browser.adding.Adding):
-    
+
     def nextURL(self):
-        return zapi.absoluteURL(self.context, self.request
-                                ) + '/@@contents.html'
+        return absoluteURL(self.context, self.request) + '/@@contents.html'
